%define debug_package %{nil}

%global _python_bytecompile_extra 0

%global __requires_exclude perl\\(Exporter\\)|perl\\(XSLoader\\)

%define with_docs 0

Summary:	A framework for configuring, compiling and installing applications
Name:		waf
Version:	2.0.22
Release:	%mkrel 4
License:	BSD and Python
Group:		Development/Tools
Url:		https://waf.io/
Source0:	waf-%{version}.stripped.tar.xz
Source1:        macros.waf
Source3:	repack.sh
Patch0:		waf-1.8.11-libdir.patch
Patch1:		waf-1.6.9-logo.patch
Patch2:		waf-1.8.11-sphinx-no-W.patch
Patch3:		pyext-linking.patch
BuildArch:	noarch
BuildRequires:	pkgconfig(python3)
%if %{with_docs}
BuildRequires:	python3-sphinx
BuildRequires:	graphviz
BuildRequires:	imagemagick
Recommends:	%{name}-doc
%endif
BuildConflicts:	waf
Requires:       python(abi) = %{python3_version}
Provides:       waf-python3 = %{version}-%{release}
Obsoletes:    waf-python3

%description
Waf is a Python-based framework for configuring, compiling and installing
applications. It derives from the concepts of other build tools such as
Scons, Autotools, CMake, and Ant.

%if %{with_docs}
%package -n %{name}-doc
Summary:	Documentation for %{name}
Group:		Documentation

%description -n %{name}-doc
Waf is a Python-based framework for configuring, compiling and
installing applications. It is a replacement for other tools such as
Autotools, Scons, CMake or Ant.
This package contains the HTML documentation for %{name}.
%endif

%prep
%setup -q
%apply_patches

# remove BOM, causes trouble later
sed -i -e '1s/^\xEF\xBB\xBF//' waflib/extras/dpapi.py

# add missing quotes, see rhbz#914566 and
# https://code.google.com/p/waf/issues/detail?id=1263
sed -i -e 's@fontname=\(Vera.*sans\),@fontname="\1",@g' \
	docs/sphinx/conf.py \
	docs/sphinx/coremodules.rst \
	docs/sphinx/featuremap.rst

%build
extras=
for f in waflib/extras/*.py ; do
	f=$(basename "$f" .py);
	if [ "$f" != "__init__" ]; then
		extras="${extras:+$extras,}$f" ;
	fi
done
%{__python3} ./waf-light --make-waf --strip --tools="$extras"

%if %{with_docs}
# build html docs
pushd docs/sphinx
../../waf configure build
popd
%endif

%install
# use waf so it unpacks itself
mkdir -p _temp
pushd _temp
  cp -av ../waf .
  %{__python3} ./waf >/dev/null 2>&1
  pushd .waf3-%{version}-*
    find . -name '*.py' -printf '%%P\0' |
	xargs -0 -I{} install -m 0644 -p -D {} %{buildroot}%{_datadir}/waf3/{}
  popd
popd

install -m 0755 -p -D waf-light %{buildroot}%{_bindir}/waf-%{python3_version}

ln -s waf-%{python3_version} %{buildroot}%{_bindir}/waf

# remove shebangs from and fix EOL for all scripts in wafadmin
find %{buildroot}%{_datadir}/ -name '*.py' \
	-exec sed -i -e '1{/^#!/d}' -e 's|\r$||g' {} \;

# fix waf script shebang line
sed -i "1c#! %{__python3}" %{buildroot}%{_bindir}/waf-%{python3_version}

# remove x-bits from everything going to doc
find demos utils -type f -exec chmod 0644 {} \;

# remove hidden file
rm -f docs/sphinx/build/html/.buildinfo

# install waf rpm macro helper
install -D %{SOURCE1} %{buildroot}%{_sysconfdir}/rpm/macros.d/%{name}.macros
# do byte compilation
%py_byte_compile %{__python3} %{buildroot}%{_datadir}/waf3

%if %{with_docs}
%files -n %{name}-doc
%doc docs/sphinx/build/html
%doc README* ChangeLog demos
%endif

%files
%{_sysconfdir}/rpm/macros.d/%{name}.macros
%{_bindir}/%{name}
%{_bindir}/%{name}-%{python3_version}
%{_datadir}/waf3/


%changelog
* Mon Apr 25 2022 TerryN <terryn94 at gmail.com> 2.0.22-4pclos2022
- rebuild for python 3.10

* Fri Oct 15 2021 tex - 2.0.22-3pclos2021
- rebuild against updates

* Fri Oct 15 2021 tex - 2.0.22-2pclos2021
- adjust spec file
